tlslite.integration.pop3_tls.POP3_TLS

Package tlslite :: Package integration :: Module pop3_tls :: Class POP3_TLS |
[hide private]
[frames] | no frames]

# Class POP3_TLS

source code

                  poplib.POP3 --+
                                |
                   object --+   |
                            |   |
    clienthelper.ClientHelper --+
                                |
                               POP3_TLS

This class extends `poplib.POP3` with TLS support.

Instance Methods | [hide private]
__init__(self, host, port=995, timeout=<object object at 0x108104550>, username=None, password=None, certChain=None, privateKey=None, checker=None, settings=None) Create a new POP3_TLS. | source code
Inherited from `poplib.POP3`: `apop`, `dele`, `getwelcome`, `list`, `noop`, `pass_`, `quit`, `retr`, `rpop`, `rset`, `set_debuglevel`, `stat`, `top`, `uidl`, `user` Inherited from `poplib.POP3` (private): `_getline`, `_getlongresp`, `_getresp`, `_longcmd`, `_putcmd`, `_putline`, `_shortcmd` Inherited from `clienthelper.ClientHelper` (private): `_handshake` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `poplib.POP3`: `timestamp`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, host, port=995, timeout=<object object at 0x108104550>, username=None, password=None, certChain=None, privateKey=None, checker=None, settings=None) (Constructor) | source code
Create a new POP3_TLS. For client authentication, use one of these argument combinations: username, password (SRP) certChain, privateKey (certificate) For server authentication, you can either rely on the implicit mutual authentication performed by SRP or you can do certificate-based server authentication with one of these argument combinations: x509Fingerprint Certificate-based server authentication is compatible with SRP or certificate-based client authentication. The caller should be prepared to handle TLS-specific exceptions. See the client handshake functions in tlslite.TLSConnection.TLSConnection for details on which exceptions might be raised. Parameters: `host` (str) - Server to connect to. `port` (int) - Port to connect to. `username` (str) - SRP username. `password` (str) - SRP password for mutual authentication. Requires the 'username' argument. `certChain` (tlslite.x509certchain.X509CertChain) - Certificate chain for client authentication. Requires the 'privateKey' argument. Excludes the SRP argument. `privateKey` (tlslite.utils.rsakey.RSAKey) - Private key for client authentication. Requires the 'certChain' argument. Excludes the SRP argument. `checker` (tlslite.checker.Checker) - Callable object called after handshaking to evaluate the connection and raise an Exception if necessary. `settings` (tlslite.handshakesettings.HandshakeSettings) - Various settings which can be used to control the ciphersuites, certificate types, and SSL/TLS versions offered by the client. Overrides: object.__init__